@@ -10,11 +10,13 @@ import os
 from pathlib import Path
 from typing import NoReturn
 
-from ozi.filter import underscorify
+from ozi_templates import load_environment  # type: ignore
+from ozi_templates.filter import underscorify  # type: ignore
+
 from ozi.fix.missing import report
 from ozi.fix.parser import parser
 from ozi.fix.rewrite_command import Rewriter
-from ozi.render import load_environment
+from ozi.spec import METADATA
 from ozi.tap import TAP
 
 
@@ -31,7 +33,7 @@ def main() -> NoReturn:  # pragma: no cover
     project.add = list(set(project.add))
     project.remove.remove('ozi.phony')
     project.remove = list(set(project.remove))
-    env = load_environment(vars(project))
+    env = load_environment(vars(project), METADATA.asdict())
 
     match [project.missing, project.strict]:
         case [True, False]:
@@ -51,7 +53,10 @@ def main() -> NoReturn:  # pragma: no cover
                 rewriter = Rewriter(str(project.target), project.name, project.fix, env)
                 rewriter += project.add
                 rewriter -= project.remove
-            print(json.dumps(rewriter.commands, indent=4 if project.pretty else None))
+            if len(project.add) > 0 or len(project.remove) > 0:
+                print(json.dumps(rewriter.commands, indent=4 if project.pretty else None))
+            else:
+                parser.print_help()
         case [True, True]:
             with TAP.strict():
                 name, *_ = report(project.target)
