@@ -8,9 +8,29 @@ from __future__ import annotations
 import re
 import shlex
 import sys
+from itertools import chain
 from pathlib import Path
 from typing import TYPE_CHECKING
 
+from ozi_templates import load_environment  # type: ignore
+
+from ozi.new.interactive import interactive_prompt
+from ozi.new.parser import parser
+from ozi.new.validate import valid_classifier
+from ozi.new.validate import valid_contact_info
+from ozi.new.validate import valid_copyright_head
+from ozi.new.validate import valid_emails
+from ozi.new.validate import valid_home_page
+from ozi.new.validate import valid_license
+from ozi.new.validate import valid_project_name
+from ozi.new.validate import valid_project_url
+from ozi.new.validate import valid_spdx
+from ozi.new.validate import valid_summary
+from ozi.render import render_ci_files_set_user
+from ozi.render import render_project_files
+from ozi.spec import METADATA
+from ozi.tap import TAP
+
 if TYPE_CHECKING:
     from argparse import Namespace
     from typing import Callable
@@ -20,21 +40,6 @@ if TYPE_CHECKING:
 
     Composable: TypeAlias = Callable[[Namespace], Namespace]
 
-from ozi.new.parser import parser
-from ozi.new.validate import valid_contact_info
-from ozi.new.validate import valid_copyright_head
-from ozi.new.validate import valid_emails
-from ozi.new.validate import valid_home_page
-from ozi.new.validate import valid_license
-from ozi.new.validate import valid_project_name
-from ozi.new.validate import valid_project_url
-from ozi.new.validate import valid_spdx
-from ozi.new.validate import valid_summary
-from ozi.render import load_environment
-from ozi.render import render_ci_files_set_user
-from ozi.render import render_project_files
-from ozi.tap import TAP
-
 
 def create_project_files(
     project: Namespace,
@@ -44,6 +49,13 @@ def create_project_files(
     project.allow_file = set(map(Path, project.allow_file))
     project.ci_user = render_ci_files_set_user(env, project.target, project.ci_provider)
     render_project_files(env, project.target, project.name)
+    if project.ci_provider == 'github':
+        Path(
+            project.target,
+            f'README.{project.long_description_content_type}',
+        ).symlink_to(Path(project.target, 'README'))
+    else:  # pragma: no cover
+        pass
 
 
 def _valid_project(project: Namespace) -> Namespace:
@@ -68,6 +80,14 @@ def _valid_project(project: Namespace) -> Namespace:
         author_email=project.author_email,
         maintainer_email=project.maintainer_email,
     )
+    for i in [
+        project.audience,
+        project.environment,
+        project.framework,
+        project.topic,
+    ]:
+        for classifier in i:
+            valid_classifier(classifier)
     return project
 
 
@@ -97,8 +117,8 @@ def postprocess_arguments(project: Namespace) -> Namespace:
     ):  # defer to good-issue
         TAP.not_ok('target directory not empty', 'no files will be created', skip=True)
     match project.ci_provider:
-        case 'github':
-            ...
+        case 'github':  # pragma: no cover
+            pass
         case _:
             TAP.not_ok(
                 f'--ci-provider "{project.ci_provider}" unrecognized. ci_user will not be set.',
@@ -111,23 +131,33 @@ def project(project: Namespace) -> None:
     project = postprocess_arguments(preprocess_arguments(project))
     create_project_files(
         project=project,
-        env=load_environment(vars(project)),
+        env=load_environment(vars(project), METADATA.asdict()),
     )
 
 
 def wrap(project: Namespace) -> None:  # pragma: no cover
     """Create a new wrap file for publishing. Not a public function."""
-    env = load_environment(vars(project))
+    env = load_environment(vars(project), METADATA.asdict())
     template = env.get_template('ozi.wrap.j2')
-    with open('ozi.wrap', 'w') as f:
+    with open('ozi.wrap', 'w', encoding='UTF-8') as f:
         f.write(template.render())
 
 
-def main() -> None:  # pragma: no cover
+def main(args: list[str] | None = None) -> None:  # pragma: no cover
     """Main ozi.new entrypoint."""
-    ozi_new = parser.parse_args()
-    ozi_new.argv = shlex.join(sys.argv[1:])
+    pipe = sys.stdin if not sys.stdin.isatty() else None
+    args = (
+        list(chain.from_iterable([shlex.split(line.strip()) for line in pipe]))
+        if pipe
+        else args
+    )
+    ozi_new = parser.parse_args(args=args)
+    ozi_new.argv = args if args else shlex.join(sys.argv[1:])
     match ozi_new:
+        case ozi_new if ozi_new.new in ['i', 'interactive']:
+            args = interactive_prompt(ozi_new)
+            ozi_new = parser.parse_args(args=args)
+            main(args)
         case ozi_new if ozi_new.new in ['p', 'project']:
             project(ozi_new)
             TAP.end()
