@@ -2,7 +2,8 @@
 # Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
 # See LICENSE.txt for license information.
 # SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-"""``ozi-new`` argparse argument parser."""
+"""``ozi-new`` console application.
+"""
 from __future__ import annotations
 
 import argparse
@@ -15,30 +16,72 @@ parser = argparse.ArgumentParser(
     prog='ozi-new',
     description=sys.modules[__name__].__doc__,
     add_help=False,
+    usage="""%(prog)s [options] | [positional args]
+
+The information provided on this application does not, and is not intended to,
+constitute legal advice. All information, content, and materials available
+on this application are for general informational purposes only.
+Information on this application may not constitute the most up-to-date legal
+or other information.
+
+THE LICENSE TEMPLATES, LICENSE IDENTIFIERS, LICENSE CLASSIFIERS, AND
+LICENSE EXPRESSION PARSING SERVICES, AND ALL OTHER CONTENTS ARE PROVIDED
+"AS IS", NO REPRESENTATIONS ARE MADE THAT THE CONTENT IS ERROR-FREE
+AND/OR APPLICABLE FOR ANY PURPOSE, INCLUDING MERCHANTABILITY.
+
+Readers of this disclaimer should contact their attorney to obtain advice
+with respect to any particular legal matter. The OZI Project is not a
+law firm and does not provide legal advice. No reader or user of this
+application should act or abstain from acting on the basis of information
+on this application without first seeking legal advice from counsel in the
+relevant jurisdiction. Legal counsel can ensure that the information
+provided in this application is applicable to your particular situation.
+Use of, or reading, this application or any of resources contained within
+does not create an attorney-client relationship.""",
+)
+subparser = parser.add_subparsers(help='', metavar='', dest='new')
+interactive_parser = subparser.add_parser(
+    'interactive',
+    aliases=['i'],
+    description='Create a new Python project with OZI.',
+    help='',
+    prog='ozi-new interactive',
+    usage='%(prog)s [options] | [positional arguments]',
 )
-subparser = parser.add_subparsers(help='create new projects, sources, & tests', dest='new')
 project_parser = subparser.add_parser(
     'project',
     aliases=['p'],
     description='Create a new Python project with OZI.',
-    add_help=False,
+    help='create new OZI project',
+    prog='ozi-new project',
+    usage='%(prog)s [options] [PKG-INFO required] [PKG-INFO optional] [PKG-INFO defaults] [defaults] target',  # noqa: B950,E501,RUF100
 )
-wrap_parser = subparser.add_parser(
-    'wrap',
-    aliases=['w'],
-    description='Create a new OZI wrapdb file.',
+interactive_parser.add_argument(
+    'target',
+    type=str,
+    nargs='?',
+    default='.',
+    help='directory path for new project (default: current working directory)',
+)
+interactive_defaults = interactive_parser.add_argument_group('defaults')
+interactive_defaults.add_argument(
+    '-c',
+    '--check-package-exists',
+    default=True,
+    action=argparse.BooleanOptionalAction,
 )
 required = project_parser.add_argument_group('PKG-INFO required')
-ozi_required = project_parser.add_argument_group('required')
-ozi_defaults = project_parser.add_argument_group('defaults')
 optional = project_parser.add_argument_group('PKG-INFO optional')
 defaults = project_parser.add_argument_group('PKG-INFO defaults')
+ozi_defaults = project_parser.add_argument_group('defaults')
+ozi_required = project_parser.add_argument_group('required')
 ozi_defaults.add_argument(
+    '-c',
     '--copyright-head',
     type=str,
     default='',
     help='copyright header string',
-    metavar='Part of the NAME project.\\nSee LICENSE...',
+    metavar='HEADER',
 )
 ozi_defaults.add_argument(
     '--ci-provider',
@@ -53,16 +96,15 @@ required.add_argument(
     '--name',
     type=str,
     help='Name (Single Use)',
-    required=True,
 )
 required.add_argument(
     '-a',
     '--author',
     type=str,
     help='Author (Multiple Use, Single output)',
-    required=True,
     action='append',
     default=[],
+    metavar='AUTHOR_NAMES',
     nargs='?',
 )
 required.add_argument(
@@ -70,8 +112,8 @@ required.add_argument(
     '--author-email',
     type=str,
     help='Author-email (Multiple Use, Single output)',
-    required=True,
     default=[],
+    metavar='AUTHOR_EMAILS',
     nargs='?',
     action='append',
 )
@@ -80,20 +122,17 @@ required.add_argument(
     '--summary',
     type=str,
     help='Summary (Single Use)',
-    required=True,
 )
 required.add_argument(
     '-p',
     '--home-page',
     type=str,
     help='Home-page (Single Use)',
-    required=True,
 )
 required.add_argument(
     '--license-expression',
     type=str,
     help='Classifier: License Expression (Single Use, SPDX Expression)',
-    required=True,
 )
 required.add_argument(
     '-l',
@@ -101,50 +140,48 @@ required.add_argument(
     type=str,
     help='Classifier: License (Single Use)',
     action=CloseMatch,
-    required=True,
 )
 ozi_required.add_argument(
     'target',
     type=str,
-    help='target directory for new project',
-)
-project_output = project_parser.add_mutually_exclusive_group()
-project_output.add_argument(
-    '-h',
-    '--help',
-    action='help',
-    help='show this help message and exit',
+    nargs='?',
+    default='.',
+    help='directory path for new project',
 )
 defaults.add_argument(
     '--audience',
     '--intended-audience',
+    metavar='AUDIENCE_NAMES',
     type=str,
-    help='Classifier: Intended Audience (Multiple Use)(default: ["Other Audience"])',
+    help='Classifier: Intended Audience (Multiple Use), default: ["Other Audience"]',
     default=METADATA.spec.python.pkg.info.classifiers.intended_audience,
     nargs='?',
-    action=CloseMatch,
+    action='append',
 )
 defaults.add_argument(
     '--typing',
     type=str,
     choices=frozenset(('Typed', 'Stubs Only')),
     nargs='?',
-    help='Classifier: Typing (Multiple Use)(default: [Typed])',
+    metavar='PY_TYPED_OR_STUBS',
+    help='Classifier: Typing (Multiple Use), default: ["Typed"]',
     default=METADATA.spec.python.pkg.info.classifiers.typing,
 )
 defaults.add_argument(
     '--environment',
+    metavar='ENVIRONMENT_NAMES',
     default=METADATA.spec.python.pkg.info.classifiers.environment,
-    help='Classifier: Environment (Multiple Use)(default: ["Other Environment"])',
-    action=CloseMatch,
+    help='Classifier: Environment (Multiple Use), default: ["Other Environment"]',
+    action='append',
     nargs='?',
     type=str,
 )
 defaults.add_argument(
     '--license-file',
     default='LICENSE.txt',
+    metavar='LICENSE_FILENAME',
     choices=frozenset(('LICENSE.txt',)),
-    help='Classifier: License File (Single Use)(default: LICENSE.txt)',
+    help='Classifier: License File (Single Use), default: "LICENSE.txt"',
     type=str,
 )
 optional.add_argument(
@@ -158,19 +195,22 @@ optional.add_argument(
     default=[],
     action='append',
     nargs='?',
+    metavar='MAINTAINER_NAMES',
     help='Maintainer (Multiple Use, Single output, if different from Author)',
 )
 optional.add_argument(
     '--maintainer-email',
     help='Maintainer-Email (Multiple Use, Single output, if different from Author-Email)',
     action='append',
+    metavar='MAINTAINER_EMAILS',
     default=[],
     nargs='?',
 )
 optional.add_argument(
     '--framework',
     help='Classifier: Framework (Multiple Use)',
-    action=CloseMatch,
+    metavar='FRAMEWORK_NAMES',
+    action='append',
     type=str,
     nargs='?',
     default=[],
@@ -179,15 +219,17 @@ optional.add_argument(
     '--project-url',
     help='Project-URL (Multiple Use, Comma-separated Tuple[name, url])',
     action='append',
+    metavar='PROJECT_URLS',
     default=[],
     nargs='?',
 )
 defaults.add_argument(
     '--language',
     '--natural-language',
+    metavar='LANGUAGE_NAMES',
     default=['English'],
-    help='Classifier: Natural Language (Multiple Use)(default: [English])',
-    action=CloseMatch,
+    help='Classifier: Natural Language (Multiple Use), default: ["English"]',
+    action='append',
     type=str,
     nargs='?',
 )
@@ -195,7 +237,8 @@ optional.add_argument(
     '--topic',
     help='Classifier: Topic (Multiple Use)',
     nargs='?',
-    action=CloseMatch,
+    metavar='TOPIC_NAMES',
+    action='append',
     type=str,
     default=[],
 )
@@ -204,17 +247,27 @@ defaults.add_argument(
     '--development-status',
     action=CloseMatch,
     default=METADATA.spec.python.pkg.info.classifiers.development_status,
-    help='Classifier: Development Status (Single Use)(default: "1 - Planning")',
+    help='Classifier: Development Status (Single Use), default: "1 - Planning"',
     type=str,
 )
+defaults.add_argument(
+    '--long-description-content-type',
+    '--readme-type',
+    metavar='README_TYPE',
+    default='rst',
+    choices=('rst', 'md', 'txt'),
+    help='Description-Content-Type',
+)
 optional.add_argument(
     '-r',
     '--dist-requires',
-    help='Dist-Requires (Multiple Use)',
+    '--requires-dist',
+    help='Requires-Dist (Multiple Use)',
     action='append',
     type=str,
     nargs='?',
     default=[],
+    metavar='DIST_REQUIRES',
 )
 output = parser.add_mutually_exclusive_group()
 output.add_argument('-h', '--help', action='help', help='show this help message and exit')
@@ -222,20 +275,27 @@ ozi_defaults.add_argument(
     '--verify-email',
     default=False,
     action=argparse.BooleanOptionalAction,
-    help='verify email domain deliverability(default: --no-verify-email)',
+    help='verify email domain deliverability, default: no',
+)
+ozi_defaults.add_argument(
+    '--enable-cython',
+    default=False,
+    action=argparse.BooleanOptionalAction,
+    help='build extension module with Cython, default: no',
 )
 ozi_defaults.add_argument(
     '--strict',
     default=False,
     action=argparse.BooleanOptionalAction,
-    help='strict mode raises warnings to errors(default: --strict)',
+    help='strict mode raises warnings to errors, default',
 )
 ozi_defaults.add_argument(
     '--allow-file',
-    help='Add a file to the allow list for new project target folder(default: [templates, .git])',
+    help='Add a file to the allow list for new project target folder, default: [templates,.git]',
     action='append',
     type=str,
     nargs='?',
+    metavar='ALLOW_FILE_PATTERNS',
     default=METADATA.spec.python.src.allow_files,
 )
 tools = parser.add_mutually_exclusive_group()  # pragma: no cover
