@@ -2,70 +2,25 @@
 # Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
 # See LICENSE.txt for license information.
 # SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-"""Rendering utilities for the OZI project templates."""
-from functools import _lru_cache_wrapper
-from functools import lru_cache
+"""Rendering utilities for the OZI project templates.
+"""
+from __future__ import annotations
+
 from pathlib import Path
-from types import FunctionType
+from typing import TYPE_CHECKING
+from typing import AnyStr
+from typing import Literal
 from warnings import warn
 
 from git import InvalidGitRepositoryError
 from git import Repo
-from jinja2 import Environment
-from jinja2 import PackageLoader
-from jinja2 import TemplateNotFound
-from jinja2 import select_autoescape
+from ozi_templates.filter import underscorify  # type: ignore
 
-from ozi.filter import current_date
-from ozi.filter import next_minor
-from ozi.filter import sha256sum
-from ozi.filter import to_distribution
-from ozi.filter import underscorify
-from ozi.filter import wheel_repr
 from ozi.spec import METADATA
 from ozi.tap import TAP
 
-FILTERS = (
-    next_minor,
-    to_distribution,
-    underscorify,
-    zip,
-    sha256sum,
-    wheel_repr,
-    current_date,
-)
-
-
-@lru_cache
-def _init_environment() -> Environment:
-    """Initialize the rendering environment, set filters, and set global metadata."""
-    env = Environment(
-        loader=PackageLoader('ozi'),
-        autoescape=select_autoescape(),
-        enable_async=True,
-        auto_reload=False,
-    )
-    for f in FILTERS:
-        match f:
-            case type():
-                env.filters.setdefault(f.__name__, f)
-            case FunctionType():
-                env.filters.setdefault(f.__name__, f)
-            case _lru_cache_wrapper():  # pragma: defer to pyright,mypy
-                env.filters.setdefault(f.__wrapped__.__name__, f)
-    env.globals = env.globals | METADATA.asdict()
-    return env
-
-
-def load_environment(project: dict[str, str]) -> Environment:
-    """Load the rendering environment for templates.
-
-    :return: jinja2 rendering environment for OZI
-    :rtype: Environment
-    """
-    env = _init_environment()
-    env.globals = env.globals | {'project': project}
-    return env
+if TYPE_CHECKING:
+    from jinja2 import Environment
 
 
 def find_user_template(target: str, file: str, fix: str) -> str | None:
@@ -82,7 +37,7 @@ def find_user_template(target: str, file: str, fix: str) -> str | None:
     """
     fp = Path(target, 'templates', fix, file)
     if fp.exists():
-        with open(fp) as template:
+        with open(fp, encoding='UTF-8') as template:
             user_template = template.read()
     else:
         TAP.diagnostic('User tempate not found', str(fp))
@@ -90,6 +45,67 @@ def find_user_template(target: str, file: str, fix: str) -> str | None:
     return user_template
 
 
+def map_to_template(
+    fix: Literal['source', 'root', 'test'] | AnyStr,
+    filename: str,
+) -> str:
+    """Map an appropriate template for an ozi-fix mode and filename.
+
+    .. versionadded:: 1.5
+
+    :param fix: ozi-fix mode setting
+    :type fix: Literal['source', 'root', 'test'] | AnyStr
+    :param filename: name with file extension
+    :type filename: str
+    :return: template path
+    :rtype: str
+    """
+    match fix, filename:
+        case ['test' | 'root', f] if f.endswith('.py'):
+            x = 'tests/new_test.py.j2'
+        case ['source', f] if f.endswith('.py'):
+            x = 'project.name/new_module.py.j2'
+        case ['source', f] if f.endswith('.pyx'):  # pragma: no cover
+            x = 'project.name/new_ext.pyx.j2'
+        case ['root', f]:
+            x = f'{f}.j2'
+        case ['source', f]:
+            x = f'project.name/{f}.j2'
+        case ['test', f]:
+            x = f'tests/{f}.j2'
+        case [_, _]:  # pragma: no cover
+            x = ''
+    return x
+
+
+def build_file(
+    env: Environment,
+    fix: Literal['source', 'root', 'test'] | AnyStr,
+    path: Path,
+    user_template: str | None,
+) -> None:
+    """Render project file based on OZI templates.
+
+    .. versionadded:: 1.5
+
+    :param env: rendering environment
+    :type env: Environment
+    :param fix: ozi-fix setting
+    :type fix: Literal['source', 'root', 'test'] | AnyStr
+    :param path: full path of file to be rendered
+    :type path: Path
+    :param user_template: path to a user template to extend
+    :type user_template: str | None
+    """
+    try:
+        template = env.get_template(map_to_template(fix, path.name)).render(
+            user_template=user_template,
+        )
+        path.write_text(template)
+    except LookupError as e:
+        warn(str(e), RuntimeWarning)
+
+
 def build_child(env: Environment, parent: str, child: Path) -> None:
     """Add a child directory to a parent in an existing OZI-style project.
 
@@ -110,12 +126,12 @@ def build_child(env: Environment, parent: str, child: Path) -> None:
             stacklevel=0,
         )
     else:
-        with open((child / 'meson.build'), 'x') as f:
+        with open((child / 'meson.build'), 'x', encoding='UTF-8') as f:
             f.write(env.get_template('new_child.j2').render(parent=parent))
 
 
 def render_ci_files_set_user(env: Environment, target: Path, ci_provider: str) -> str:
-    """Render CI files based on the ci_provider for target in env.
+    """Render :term:`CI` files based on the ci_provider for target in env.
 
     :param env: the OZI project file rendering environment
     :type env: jinja2.Environment
@@ -133,14 +149,36 @@ def render_ci_files_set_user(env: Environment, target: Path, ci_provider: str) -
             except InvalidGitRepositoryError:
                 ci_user = ''
             Path(target, '.github', 'workflows').mkdir(parents=True)
-            template = env.get_template('github_workflows/ozi.yml.j2')
-            with open(Path(target, '.github', 'workflows', 'ozi.yml'), 'w') as f:
-                f.write(template.render())
+            for i in ['ozi.yml', 'cleanup.yml']:
+                template = env.get_template(f'github_workflows/{i}.j2')
+                with open(
+                    Path(target, '.github', 'workflows', i),
+                    'w',
+                    encoding='UTF-8',
+                ) as f:
+                    f.write(template.render())
         case _:  # pragma: no cover
             ci_user = ''
     return ci_user
 
 
+def render_templates(env: Environment, target: Path) -> None:
+    """Render a project :file:`templates/` directory.
+
+    .. versionadded: 1.13
+
+    :param env: the OZI project file rendering environment
+    :type env: jinja2.Environment
+    :param target: directory path to render the project
+    :type target: Path
+    """
+    for i in ['.release_notes.md.j2', 'CHANGELOG.md.j2', '.parsed_commit_heading.j2']:
+        template = env.get_template(f'templates/{i}')
+        f = target / 'templates' / i
+        f.parent.mkdir(exist_ok=True, parents=True)
+        f.write_text(template.render())
+
+
 def render_project_files(env: Environment, target: Path, name: str) -> None:
     """Render the primary new project files(excluding CI).
 
@@ -159,23 +197,30 @@ def render_project_files(env: Environment, target: Path, name: str) -> None:
         template = env.get_template(f'{filename}.j2')
         try:
             content = template.render(filename=filename)
-        except TemplateNotFound:  # pragma: defer to good-first-issue
+        except LookupError:  # pragma: defer to good-first-issue
             content = f'template "{filename}" failed to render.'
             warn(content, RuntimeWarning, stacklevel=0)
-        with open(target / filename, 'w') as f:
+        with open(target / filename, 'w', encoding='UTF-8') as f:
             f.write(content)
 
     for filename in templates.source:
-        template = env.get_template(f'{filename}.j2')
         filename = filename.replace('project.name', underscorify(name).lower())
-        with open(target / filename, 'w') as f:
-            f.write(template.render())
+        build_file(
+            env,
+            'source',
+            target / filename,
+            find_user_template(str(target), filename, 'source'),
+        )
 
     for filename in templates.test:
-        template = env.get_template(f'{filename}.j2')
-        with open(target / filename, 'w') as f:
-            f.write(template.render())
+        build_file(
+            env,
+            'test',
+            target / filename,
+            find_user_template(str(target), filename, 'test'),
+        )
 
     template = env.get_template('project.ozi.wrap.j2')
-    with open(target / 'subprojects' / 'ozi.wrap', 'w') as f:
+    with open(target / 'subprojects' / 'ozi.wrap', 'w', encoding='UTF-8') as f:
         f.write(template.render())
+    render_templates(env, target)
