@@ -5,12 +5,18 @@
 """Specification API for OZI Metadata."""
 from ozi.spec._spec import OZI
 from ozi.spec._spec import Metadata
+from ozi.spec._spec import Spec
 from ozi.spec._spec import current_version
+from ozi.spec.base import Default
+from ozi.spec.src import CommentPatterns
 
 __all__ = (
+    'CommentPatterns',
+    'Default',
     'METADATA',
     'Metadata',
     'OZI',
+    'Spec',
     'current_version',
 )
 
