@@ -3,6 +3,7 @@
 # See LICENSE.txt for license information.
 # SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 """Continuous integration specification."""
+from __future__ import annotations
 
 from collections.abc import Mapping  # noqa: TCH003,TC003,RUF100
 from dataclasses import dataclass
@@ -16,14 +17,21 @@ class Publish(Default):
     """Publishing patterns for packaged project."""
 
     include: tuple[str, ...] = ('*.tar.gz', '*.whl', 'sig/*')
-    version: str = '0.1.0'
+    version: str = '0.1.6'
+
+
+@dataclass(slots=True, frozen=True, eq=True)
+class Draft(Default):
+    """Draft release patterns for packaged project."""
+
+    version: str = '0.3.3'
 
 
 @dataclass(slots=True, frozen=True, eq=True)
 class Release(Default):
     """Release patterns for packaged project."""
 
-    version: str = '0.1.17'
+    version: str = '0.6.5'
 
 
 @dataclass(slots=True, frozen=True, eq=True)
@@ -31,10 +39,10 @@ class Checkpoint(Default):
     """Checkpoint suites to run."""
 
     suites: tuple[str, ...] = ('dist', 'lint', 'test')
-    version: str = '0.1.5'
+    version: str = '0.4.2'
 
 
-@dataclass(kw_only=True, frozen=True, eq=True)
+@dataclass(slots=True, frozen=True, eq=True)
 class CheckpointSuite(Default):
     """OZI checkpoint base class."""
 
@@ -106,7 +114,7 @@ class ClassicLint(CheckpointSuite):
             'isort': 'isort',
             'mypy': 'mypy',
             'pyright': 'pyright',
-            'restructuredtext-lint': 'restructuredtext-lint',
+            'readme-renderer': 'readme-renderer[md]',
         },
     )
     plugin: Mapping[str, str] = field(
@@ -171,15 +179,13 @@ class ClassicDist(CheckpointSuite):
 class Build(Default):
     """Build backend and required packages for OZI."""
 
-    backend: str = 'mesonpep517.buildapi'
+    backend: str = 'ozi_build.buildapi'
     requires: Mapping[str, str] = field(
         default_factory=lambda: {
-            'mesonpep517': 'mesonpep517==0.2',
-            'meson': 'meson[ninja]>=1.1.0',
+            'OZI.build': 'OZI.build>=0.0.26',
             'pip-tools': 'pip-tools>=7',
-            'setuptools': 'setuptools>=64',
-            'setuptools_scm': 'setuptools_scm>=8.0',
-            'tomli': 'tomli>=2.0.0;python_version<"3.11"',
+            'pipx': 'pipx~=1.5',
+            'setuptools_scm': 'setuptools_scm[toml]~=8.0',
         },
     )
 
@@ -192,6 +198,7 @@ class CI(Default):
         default_factory=lambda: {'tox': 'tox>4', 'tox-gh': 'tox-gh>1.2'},
     )
     checkpoint: Checkpoint = Checkpoint()
+    draft: Draft = Draft()
     release: Release = Release()
     publish: Publish = Publish()
     providers: tuple[str, ...] = ('github',)
